package controllers

import (
	"eta/eta_mini_crm/models"
	"eta/eta_mini_crm/models/response"
	"eta/eta_mini_crm/utils"

	"github.com/rdlucklib/rdluck_tools/paging"
)

type SysRoleController struct {
	BaseAuthController
}

// List
// @Title 系统角色列表
// @Description 系统角色列表
// @Param	request	body UserLoginReq true "type json string"
// @Success 200 {object} response.SysRoleListResp
// @router /list [get]
func (this *SysRoleController) List() {
	br := new(models.BaseResponse).Init()
	defer func() {
		this.Data["json"] = br
		this.ServeJSON()
	}()

	pageSize, _ := this.GetInt("PageSize")
	currentIndex, _ := this.GetInt("CurrentIndex")

	var startSize int
	if pageSize <= 0 {
		pageSize = utils.PageSize20
	}
	if currentIndex <= 0 {
		currentIndex = 1
	}
	startSize = utils.StartIndex(currentIndex, pageSize)

	total, err := models.GetSysRoleListCount()
	if err != nil {
		br.Msg = "获取失败"
		br.ErrMsg = "获取失败，Err:" + err.Error()
		return
	}
	list, err := models.GetSysRoleList(startSize, pageSize)
	if err != nil {
		br.Msg = "获取失败"
		br.ErrMsg = "获取失败，Err:" + err.Error()
		return
	}
	page := paging.GetPaging(currentIndex, pageSize, total)
	resp := new(response.SysRoleListResp)
	resp.List = list
	resp.Paging = page
	br.Ret = 200
	br.Success = true
	br.Msg = "获取成功"
	br.Data = resp
}
